@@ -15,6 +15,7 @@ use Getopt::Long qw(:config posix_default no_ignore_case no_ignore_case_always);
 use Hash::Merge::Simple qw(clone_merge);
 use JSON::MaybeXS;
 use Pod::Usage;
+use Ref::Util qw(is_hashref);
 use Time::HiRes qw(time);
 
 #------------------------------------------------------------------------#
@@ -128,7 +129,7 @@ unless( exists $OPT{append} ) {
         },
         {
             settings => $to_settings,
-            mappings => $mappings,
+            $mappings ? ( mappings => $mappings ) : (),
         }
     );
 
@@ -226,7 +227,7 @@ es-copy-index.pl - Copy an index from one cluster to another
 
 =head1 VERSION
 
-version 6.2
+version 6.3
 
 =head1 SYNOPSIS
 
